@@ -13,24 +13,24 @@ typedef struct _xh_writer_t xh_writer_t;
 struct _xh_writer_t {
 #ifdef XH_HAVE_ENCODER
     xh_encoder_t          *encoder;
-    xh_buffer_t            enc_buf;
+    xh_perl_buffer_t       enc_buf;
 #endif
     PerlIO                *perl_io;
     SV                    *perl_obj;
-    xh_buffer_t            main_buf;
+    xh_perl_buffer_t       main_buf;
     xh_int_t               indent;
     xh_int_t               indent_count;
     xh_bool_t              trim;
 };
 
-SV *xh_writer_flush_buffer(xh_writer_t *writer, xh_buffer_t *buf);
+SV *xh_writer_flush_buffer(xh_writer_t *writer, xh_perl_buffer_t *buf);
 SV *xh_writer_flush(xh_writer_t *writer);
 void xh_writer_resize_buffer(xh_writer_t *writer, size_t inc);
 void xh_writer_destroy(xh_writer_t *writer);
-xh_writer_t *xh_writer_create(char *encoding, void *output, size_t size, xh_uint_t indent, xh_bool_t trim);
+void xh_writer_init(xh_writer_t *writer, xh_char_t *encoding, void *output, size_t size, xh_uint_t indent, xh_bool_t trim);
 
 XH_INLINE void
-xh_writer_write_to_perl_obj(xh_buffer_t *buf, SV *perl_obj)
+xh_writer_write_to_perl_obj(xh_perl_buffer_t *buf, SV *perl_obj)
 {
     size_t len = buf->cur - buf->start;
 
@@ -59,7 +59,7 @@ xh_writer_write_to_perl_obj(xh_buffer_t *buf, SV *perl_obj)
 }
 
 XH_INLINE void
-xh_writer_write_to_perl_io(xh_buffer_t *buf, PerlIO *perl_io)
+xh_writer_write_to_perl_io(xh_perl_buffer_t *buf, PerlIO *perl_io)
 {
     size_t len = buf->cur - buf->start;
 
@@ -74,7 +74,7 @@ xh_writer_write_to_perl_io(xh_buffer_t *buf, PerlIO *perl_io)
 }
 
 XH_INLINE SV *
-xh_writer_write_to_perl_scalar(xh_buffer_t *buf)
+xh_writer_write_to_perl_scalar(xh_perl_buffer_t *buf)
 {
     *buf->cur = '\0';
     SvCUR_set(buf->scalar, buf->cur - buf->start);
